@@ -51,14 +51,14 @@
 calc_gradient <- function(x, fn, h=6e-06, varying_h=NULL, ...) {
   fn <- match.fun(fn)
   n <- length(x)
-  I <- diag(1, nrow=n, ncol=n)
+  I_n <- diag(1, nrow=n, ncol=n)
   if(is.null(varying_h)) { # The same difference h for all parameters
     h <- rep(h, times=n)
   } else { # Varying h
     stopifnot(length(varying_h) == length(x))
     h <- varying_h
   }
-  vapply(1:n, function(i1) (fn(x + h[i1]*I[i1,], ...) - fn(x - h[i1]*I[i1,], ...))/(2*h[i1]), numeric(1))
+  vapply(1:n, function(i1) (fn(x + h[i1]*I_n[i1,], ...) - fn(x - h[i1]*I_n[i1,], ...))/(2*h[i1]), numeric(1))
 }
 
 
@@ -102,7 +102,8 @@ get_gradient <- function(gsmvar, custom_h=NULL) {
   foo <- function(x) {
     loglikelihood_int(data=gsmvar$data, p=gsmvar$model$p, M=gsmvar$model$M, params=x, model=gsmvar$model$model,
                       conditional=gsmvar$model$conditional, parametrization=gsmvar$model$parametrization,
-                      structural_pars=gsmvar$model$structural_pars, constraints=gsmvar$model$constraints,
+                      constraints=gsmvar$model$constraints, same_means=gsmvar$model$same_means,
+                      weight_constraints=gsmvar$model$weight_constraints, structural_pars=gsmvar$model$structural_pars,
                       to_return="loglik", check_params=TRUE, minval=NA, stat_tol=gsmvar$num_tols$stat_tol,
                       posdef_tol=gsmvar$num_tols$posdef_tol, df_tol=gsmvar$num_tols$df_tol)
   }
@@ -125,7 +126,8 @@ get_hessian <- function(gsmvar, custom_h=NULL) {
   foo <- function(x) {
     loglikelihood_int(data=gsmvar$data, p=gsmvar$model$p, M=gsmvar$model$M, params=x, model=gsmvar$model$model,
                       conditional=gsmvar$model$conditional, parametrization=gsmvar$model$parametrization,
-                      constraints=gsmvar$model$constraints, structural_pars=gsmvar$model$structural_pars,
+                      constraints=gsmvar$model$constraints, same_means=gsmvar$model$same_means,
+                      weight_constraints=gsmvar$model$weight_constraints, structural_pars=gsmvar$model$structural_pars,
                       to_return="loglik", check_params=TRUE, minval=NA, stat_tol=gsmvar$num_tols$stat_tol,
                       posdef_tol=gsmvar$num_tols$posdef_tol, df_tol=gsmvar$num_tols$df_tol)
   }
